@@ -17,6 +17,8 @@
  *
  */
 
+#include "config.h"
+
 #include "xapiandatabase.h"
 #include "xapiandocument.h"
 
@@ -24,9 +26,11 @@
 #include <QTimer>
 #include <QDir>
 
-#ifdef __GNUC__
+#if defined(HAVE_MALLOC_H)
 #include <malloc.h>
 #include <unistd.h>
+#else
+#include <unistd.h>
 #endif
 
 using namespace Baloo;
@@ -140,7 +144,7 @@ void XapianDatabase::commit()
     m_docsToAdd.clear();
     m_docsToRemove.clear();
 
-#ifdef __GNUC__
+#if defined(HAVE_MALLOC_TRIM)
     malloc_trim(0);
 #endif
 }
